(external_tools)=
# External tools

Here external tools related to phono3py but supported by the groups out
of the phono3py project are listed.

Each of the tools is not supported by the phono3py project because of
the difficulties of the maintenance and the test by main developers
of phono3py under current style of phono3py development. However
useful tools should be known. If developers want to use here to notify
their tools, please contact via the phonopy mailing list.

## Phono3py-Power-Tools

Phono3py-Power-Tools is a collection of codes and scripts from the Skelton group for Phono(3)py "power users", and includes additional tools for data analysis and plotting.

https://github.com/skelton-group/Phono3py-Power-Tools


## Kinetic Collective Model

The Kinetic Collective Model (KCM), developed by the nanoTransport
group of the Universitat Autònoma de Barcelona, is a generalization of
the Guyer and Krumhansl solution of the phonon Boltzmann Transport
Equation. KCM allows to compute the thermal conductivity of
semiconductors in a fast and low memory way from first principles
calculations.

https://physta.github.io/
